Django Grappelli
================
.. image:: https://api.travis-ci.org/sehmaschine/django-grappelli.svg
    :target: https://travis-ci.org/sehmaschine/django-grappelli

.. image:: https://readthedocs.org/projects/django-grappelli/badge/?version=latest
    :target: http://django-grappelli.readthedocs.org/en/latest/?badge=latest

.. image:: https://img.shields.io/pypi/v/django-grappelli.svg
    :target: https://pypi.python.org/pypi/django-grappelli

.. image:: https://img.shields.io/pypi/l/django-grappelli.svg
    :target: https://pypi.python.org/pypi/django-grappelli

**A jazzy skin for the Django admin interface**.

Grappelli is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

Code
----

https://github.com/sehmaschine/django-grappelli

Website
-------

http://www.grappelliproject.com

Documentation
-------------

http://readthedocs.org/docs/django-grappelli/

Releases
--------

**Grappelli is always developed against the latest stable Django release and is NOT tested with Django's master branch.**

* Grappelli 2.14.2 (May 14th, 2020): Compatible with Django 3.0
* Grappelli 2.13.4 (February 10th, 2020): Compatible with Django 2.2 (LTS)
* Grappelli 2.10.4 (November 1st, 2018): Compatible with Django 1.11 (LTS)

Current development branches:

* Grappelli 2.14.3 (Development version for Django 3.0, see branch Stable/2.14.x)
* Grappelli 2.13.5 (Development version for Django 2.2, see branch Stable/2.13.x)
* Grappelli 2.10.5 (Development version for Django 1.11, see branch Stable/2.10.x)

Older versions are available at GitHub, but are not supported anymore.
